@@ -1,8 +1,6 @@
-import tkinter as tk
 from random import randint
 
 from TkZero.Button import Button
-from TkZero.Label import Label
 from TkZero.MainWindow import MainWindow
 from TkZero.Progressbar import Progressbar
 
@@ -25,7 +23,7 @@ def get_bytes():
     else:
         # Just so that we don't go over the limit. In a real situation, you wouldn't need to do this.
         bar.value = bar.maximum
-    label.text = f"{round(bar.value / 1024 / 1024, 2)}/{round(bar.maximum / 1024 / 1024, 2)} MiB downloaded"
+    bar.text = f"{round(bar.value / 1024 / 1024, 2)}/{round(bar.maximum / 1024 / 1024, 2)} MiB downloaded"
 
 
 # Create a button to "start" the download
@@ -33,14 +31,11 @@ start_btn = Button(root, text="Start download", command=start_download)
 start_btn.grid(row=0, column=0)
 
 # Create a progress bar to represent the "download"
-bar = Progressbar(root, length=200)
+bar = Progressbar(root, length=500)
 bar.grid(row=1, column=0)
 bar.maximum = randint(1024*1024*128, 1024*1024*1024)
 
-# Create a label to show the exact byte counts
-label = Label(root)
-label.grid(row=2, column=0, sticky=tk.NW)
-label.text = f"File is {round(bar.maximum / 1024 / 1024, 2)} MiB"
+bar.text = f"File is {round(bar.maximum / 1024 / 1024, 2)} MiB"
 
 # Start the mainloop like in Tkinter
 root.mainloop()
